@@ -24,7 +24,7 @@ def main(clock_filename_mock=None, show_list_mock=False, time_mock=None) -> None
 
     def _main(
         clock_filename_: Optional[str] = typer.Argument(
-            None, metavar='CLOCK_FILENAME', help='indicate clock filenames' + clock_basenames),
+            None, metavar='CLOCK_FILENAME', help='clock filename' + clock_basenames),
         show_version: bool = typer.Option(False, '-v', '--version', help='show version'),
         clock_filename: Optional[str] = typer.Option(
             None, '-c', '--clock-filename', help='indicate clock filenames' + clock_basenames),
